Conda-Pack
==========

|CI Status| |Conda Badge| |PyPI Badge|

``conda-pack`` is a command line tool for creating relocatable conda
environments. This is useful for deploying code in a consistent environment,
potentially in a location where python/conda isn't already installed.

See the `documentation <https://conda.github.io/conda-pack/>`_ for more
information.

LICENSE
-------

New BSD. See the
`License File <https://github.com/conda/conda-pack/blob/master/LICENSE.txt>`_.

.. |CI Status| image:: https://github.com/conda/conda-pack/workflows/Build%20and%20test/badge.svg
   :target: https://github.com/conda/conda-pack/actions?query=workflow%3A%22Build+and+test%22
.. |Conda Badge| image:: https://img.shields.io/conda/vn/conda-forge/conda-pack.svg
   :target: https://anaconda.org/conda-forge/conda-pack
.. |PyPI Badge| image:: https://img.shields.io/pypi/v/conda-pack.svg
   :target: https://pypi.org/project/conda-pack/
